<?php namespace EscapeWork\Manager\Subscribers\Controllers;

use EscapeWork\Manager\Controllers\ManagerController;
use EscapeWork\Manager\Subscribers\Repositories\SubscriberRepository;
use EscapeWork\Manager\Services\Exporter\CSVExporter;
use View;
use Input;
use Redirect;
use Response;
use Request;

class SubscribersController extends ManagerController
{

    public function __construct(SubscriberRepository $subscriber)
    {
        $this->subscriber = $subscriber;

        # filters
        $this->enableDefaultFilters('subscribers');
    }

    /**
     * Listando os banners
     */
    public function index()
    {
        $view = View::make('manager-subscribers::subscribers.index');

        $params = Input::all();
        $query =  $this->subscriber;

        #filtros
        if (isset($params['name']) && $params['name'] != '') {
            $query = $query->where('name', 'like', '%'.$params['name'].'%');
        }

        if (isset($params['email']) && $params['email'] != '') {
            $query = $query->where('email', 'like', '%'.$params['email'].'%');
        }

        $view->ordem = 'desc';
        $view->icon = null;

        $view->column = null;

        if (Input::has('col') && Input::has('ord')) {

            $view->column = Input::get('col');

            if (Input::get('ord') == 'desc')  {
                $view->ordem = 'asc';
                $view->icon = 'icon-chevron-up';
            }

            if (Input::get('ord') == 'asc') {
                $view->ordem = 'desc';
                $view->icon = 'icon-chevron-down';
            }

            $query = $query->orderBy('subscribers.'.Input::get('col'), Input::get('ord'));
        }

        $view->subscribers = $query->paginate(20);

        return $view;
    }

    public function create()
    {
        $this->subscriber->fill(Input::old());

        $view             = View::make('manager-subscribers::subscribers.form');
        $view->subscriber = $this->subscriber;
        $view->edit       = false;

        return $view;
    }

    public function store()
    {
        $this->subscriber->fill(Input::all());

        if (! $this->subscriber->validate()) {
            if (Request::ajax()) {
                return Response::json(array(
                    'errors'     => Subscriber::$messages,
                    'subscriber' => $this->subscriber->toArray(),
                ));
            } else {
                return Redirect::route('manager.subscribers.create')
                        ->withInput()
                        ->with('errors', Subscriber::$messages);
            }
        }

        $this->subscriber->save();

        if (Request::ajax()) {
            return Response::json(array(
                'message'    => 'Cadastro realizado com sucesso',
                'subscriber' => $this->subscriber->toArray(),
            ));
        } else {
            return Redirect::route('manager.subscribers.index')
                    ->with('message', 'O contato <strong>'.$this->subscriber->name.'</strong> foi inserido com sucesso!');
        }
    }

    public function edit($id)
    {
        if (! $this->subscriber = $this->subscriber->find($id)) {
            return Redirect::route('manager.subscribers.index')
                    ->with('error', 'Contato não encontrado');
        }

        $this->subscriber->fill(Input::old());

        $view             = View::make('manager-subscribers::subscribers.form');
        $view->subscriber = $this->subscriber;
        $view->edit       = true;

        return $view;
    }

    public function update($id)
    {
        if (! $this->subscriber = $this->subscriber->find($id)) {
            return Redirect::route('manager.subscribers.index')
                    ->with('error', 'Contato não encontrado');
        }

        $this->subscriber->fill(Input::all());

        if (! $this->subscriber->validate()) {
            return Redirect::route('manager.subscribers.create')
                    ->withInput()
                    ->with('errors', Subscriber::$messages);
        }

        $this->subscriber->save();

        return Redirect::route('manager.subscribers.index')
                        ->with('message', 'O contato <strong>'.$this->subscriber->name.'</strong> foi atualizado com sucesso!');
    }

    public function destroy($id)
    {
        if (! $this->subscriber = $this->subscriber->find($id)) {
            return Redirect::route('manager.subscribers.index')
                    ->with('error', 'Contato não encontrado');
        }

        $this->subscriber->delete();

        return Redirect::route('manager.subscribers.index')
                        ->with('message', 'O contato <strong>'.$this->subscriber->name.'</strong> foi excluído com sucesso!');
    }

    /**
     * Exportando os contatos para CSV
     */
    public function export()
    {
        $subscribers = $this->subscriber->all();
        $exporter    = new CSVExporter();

        # header
        $exporter->writeLine(array(
            'ID', 'Nome', 'E-mail', 'Sexo', 'Data de Nascimento', 'Cidade', 'Estado', 'País', 'Data de cadastro', 'Data de atualização',
        ));

        foreach ($subscribers as $subscriber) {
            $exporter->writeLine($subscriber->toArray());
        }

        return $exporter->export(array('filename' => 'contatos-newsletter-'.date('Y-m-d')));
    }

    public function exportMailChimp()
    {
        $subscribers    = $this->subscriber->getNewerSubscribers();
        $this->exporter = new \EscapeWork\Manager\Subscribers\Export\MailChimpExporter();
        $this->exporter->export($subscribers);

        return 'Exportado com sucesso!';
    }
}