<?php namespace EscapeWork\Manager\Subscribers\Providers;

use EscapeWork\Manager\Subscribers\Commands\ConfigureCommand;
use EscapeWork\Manager\Subscribers\Commands\CampaignMonitorExportCommand;
use Illuminate\Support\ServiceProvider;

class ManagerSubscribersServiceProvider extends ServiceProvider
{

	/**
	 * Indicates if loading of the provider is deferred.
	 *
	 * @var bool
	 */
	protected $defer = false;

    /**
     * Bootstrap the application events.
     *
     * @return void
     */
    public function boot()
    {
        $this->package('escapework/manager-subscribers', 'manager-subscribers', realpath(__DIR__ . '/../../../../'));

        include_once(__DIR__ . '/../../../../routes.php');
    }

	/**
     * Register the service provider.
     *
     * @return void
     */
    public function register()
    {
        $this->registerCommands();
        $this->bindRepositories();
    }

    protected function bindRepositories()
    {
        $this->app->bind('EscapeWork\Manager\Subscribers\Repositories\SubscriberRepository', 'EscapeWork\Manager\Subscribers\Models\Subscriber');
    }

    protected function registerCommands()
    {
        $this->app['command.manager.subscribers.configure'] = $this->app->share(function($app)
        {
            return new ConfigureCommand;
        });

        $this->app['command.manager.subscribers.export.cm'] = $this->app->share(function($app)
        {
            return new CampaignMonitorExportCommand;
        });

        $this->commands('command.manager.subscribers.configure', 'command.manager.subscribers.export.cm');
    }

    public function provides()
    {
        return array('command.manager.subscribers.configure', 'command.manager.subscribers.export.cm');
    }

}